@@ -89,7 +89,7 @@ pub enum FsCommand {
 
 impl FsCommand {
     fn remove(path: &Path) -> io::Result<()> {
-        let _ = FileLock::new(&path)?;
+        let _ = FileLock::new(path)?;
         fs::remove_file(path.to_path_buf())
             .map_err(|e| io::Error::new(e.kind(), format!("Failed to remove file {}: {}", path, e)))
     }
@@ -174,14 +174,14 @@ impl FsCommand {
     /// If the function fails, moves the file back to the original location.
     /// If the function succeeds, removes the file permanently.
     fn safe_remove<R>(path: &Path, f: impl Fn(&Path) -> io::Result<R>, log: &Log) -> io::Result<R> {
-        let _ = FileLock::new(&path)?; // don't remove a locked file
+        let _ = FileLock::new(path)?; // don't remove a locked file
         let tmp = Self::temp_file(path);
-        Self::rename(&path, &tmp)?;
-        let result = match f(&path) {
+        Self::rename(path, &tmp)?;
+        let result = match f(path) {
             Ok(result) => result,
             Err(e) => {
                 // Try to undo the move if possible
-                if let Err(remove_err) = Self::rename(&tmp, &path) {
+                if let Err(remove_err) = Self::rename(&tmp, path) {
                     log.warn(format!(
                         "Failed to undo move from {} to {}: {}",
                         &path, &tmp, remove_err
@@ -616,7 +616,7 @@ where
 {
     groups
         .into_par_iter()
-        .flat_map(move |group| match partition(group, &config, log) {
+        .flat_map(move |group| match partition(group, config, log) {
             Ok(group) => group.dedupe_script(op),
             Err(e) => {
                 log.warn(e);
@@ -849,8 +849,12 @@ mod test {
     #[test]
     fn test_partition_respects_creation_time_priority() {
         with_dir("dedupe/partition/ctime_priority", |root| {
+            if fs::metadata(root).unwrap().created().is_err() {
+                // can't run the test because the filesystem doesn't support fetching
+                // file creation time
+                return;
+            }
             let group = make_group(root);
-
             let mut config = DedupeConfig::default();
             config.priority = vec![Priority::Newest];
             let partitioned_1 = partition(group.clone(), &config, &Log::new()).unwrap();
@@ -899,7 +903,7 @@ mod test {
         with_dir("dedupe/partition/keep", |root| {
             let group = make_group(root);
             let mut config = DedupeConfig::default();
-            config.priority = vec![Priority::Oldest];
+            config.priority = vec![Priority::LeastRecentlyModified];
             config.keep_name_patterns = vec![Pattern::glob("*_1").unwrap()];
             let p = partition(group.clone(), &config, &Log::new()).unwrap();
             assert_eq!(p.to_keep.len(), 1);
@@ -918,7 +922,7 @@ mod test {
         with_dir("dedupe/partition/drop", |root| {
             let group = make_group(root);
             let mut config = DedupeConfig::default();
-            config.priority = vec![Priority::Oldest];
+            config.priority = vec![Priority::LeastRecentlyModified];
             config.name_patterns = vec![Pattern::glob("*_3").unwrap()];
             let p = partition(group.clone(), &config, &Log::new()).unwrap();
             assert_eq!(p.to_drop.len(), 1);
@@ -937,7 +941,7 @@ mod test {
         with_dir("dedupe/partition/dedupe_script", |root| {
             let group = make_group(root);
             let mut config = DedupeConfig::default();
-            config.priority = vec![Priority::Oldest]; // remove oldest
+            config.priority = vec![Priority::LeastRecentlyModified];
             let log = Log::new();
             let script = dedupe(vec![group], DedupeOp::Remove, &config, &log);
             let dedupe_result = run_script(script, &log);
